==> sovix-0.0.1.5.tar.gz: sovix-0.0.1.5/Copyright.php <==
<?php /* Copyright (C) 2006, 2007, 2008 David Englund.

This file is part of GNU Sovix.

GNU Sovix is free software: you can redistribute it and/or modify
it under the terms of the GNU Affero General Public License as
published by the Free Software Foundation, either version 3 of the
License, or (at your option) any later version.

GNU Sovix is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU Affero General Public License for more details.

You should have received a copy of the GNU Affero General Public License
along with GNU Sovix.  If not, see <http://www.gnu.org/licenses/>.

The text in $sovix__page__copyright doesn't apply to this file, but
rather to the pages it generates. */

$sovix__page__copyright="Copyright (C) 2006, 2007, 2008 David Englund.
This entire article is distributed under the GNU Free Documentation
License, Version 1.2 or any later version.";
$sovix__directory__src=$_SERVER['DOCUMENT_ROOT']."/sovix/src";
$sovix__directory__dotsovix=$_SERVER['DOCUMENT_ROOT']."/sovix/dotsovix";
require_once "$sovix__directory__src/header.inc"; ?>

<abbr title="Gnu's Not Unix"<?php if($sovix__xhtml_plus_rdfa==true) echo ' property="dc:source"'; ?>>GNU</abbr> <?php if($sovix__xhtml_plus_rdfa==true) echo '<span property="dc:title">'; ?>Sovix<? if($sovix__xhtml_plus_rdfa==true) echo '</span>'; ?> wesite revision system version 0.0.1.5 is Copyright (C) 2006, 2007, 2008 David Englund.

<p></p>
<h3><?php if($sovix__xhtml_plus_rdfa==true) echo '<span property="dc:rights">'; ?><acronym title="GNU's Not Unix">GNU</acronym> Affero General Public License<? if($sovix__xhtml_plus_rdfa==true) echo '</span>'; ?></h3>
<p></p>
<abbr title="Gnu's Not Unix"<?php if($sovix__xhtml_plus_rdfa==true) echo ' property="dc:source"'; ?>>GNU</abbr> <?php if($sovix__xhtml_plus_rdfa==true) echo '<span property="dc:title">'; ?>Sovix<? if($sovix__xhtml_plus_rdfa==true) echo '</span>'; ?> is free software: you can redistribute it and/or modify<br<?php echo $sovix__close_tag; ?>>
it under the terms of the <?php if($sovix__xhtml_plus_rdfa==true) echo '<span property="dc:rights">'; ?><acronym title="GNU's Not Unix">GNU</acronym> Affero General Public License<? if($sovix__xhtml_plus_rdfa==true) echo '</span>'; ?> as published by<br<?php echo $sovix__close_tag; ?>>
published by the Free Software Foundation, either version 3 of the<br<?php echo $sovix__close_tag; ?>>
License, or (at your option) any later version.
<p></p>
<abbr title="Gnu's Not Unix"<?php if($sovix__xhtml_plus_rdfa==true) echo ' property="dc:source"'; ?>>GNU</abbr> <?php if($sovix__xhtml_plus_rdfa==true) echo '<span property="dc:title">'; ?>Sovix<? if($sovix__xhtml_plus_rdfa==true) echo '</span>'; ?> is distributed in the hope that it will be useful,<br<?php echo $sovix__close_tag; ?>>
but WITHOUT ANY WARRANTY; without even the implied warranty of<br<?php echo $sovix__close_tag; ?>>
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the<br<?php echo $sovix__close_tag; ?>>
<?php if($sovix__xhtml_plus_rdfa==true) echo '<span property="dc:rights">'; ?><acronym title="GNU's Not Unix">GNU</acronym> Affero General Public License<? if($sovix__xhtml_plus_rdfa==true) echo '</span>'; ?> for more details.<br<?php echo $sovix__close_tag; ?>>
<p></p>
The toolbar icons is copied from Emacs, copyright Free Software Foundation.
<p></p>
You should have received a copy of the <?php if($sovix__xhtml_plus_rdfa==true) echo '<span property="dc:rights">'; ?><acronym title="GNU's Not Unix">GNU</acronym> Affero General Public License<? if($sovix__xhtml_plus_rdfa==true) echo '</span>'; ?><br<?php echo $sovix__close_tag; ?>>
along with <abbr title="Gnu's Not Unix"<?php if($sovix__xhtml_plus_rdfa==true) echo ' property="dc:source"'; ?>>GNU</abbr> <?php if($sovix__xhtml_plus_rdfa==true) echo '<span property="dc:title">'; ?>Sovix<? if($sovix__xhtml_plus_rdfa==true) echo '</span>'; ?>.  If not, see <a href="http://www.gnu.org/licenses/">&#60;http://www.gnu.org/licenses/&#62;</a>.<br<?php echo $sovix__close_tag; ?>>
<p></p>
See <?php sovix__local_link($sovix__local_link__link="$sovix__url__sovix/COPYING",$sovix__local_link__text="&#60;$sovix__url__sovix/COPYING&#62;"); ?> for the full text of that license.

<p></p>
<h3><acronym title="GNU's Not Unix">GNU</acronym> Free Documentation License</h3>
Permission is granted to copy, distribute and/or modify <?php if($sovix__xhtml_plus_rdfa==true) echo '<span property="dc:title">'; ?>Sovix<? if($sovix__xhtml_plus_rdfa==true) echo '</span>'; ?> documents<br<?php echo $sovix__close_tag; ?>>
under the terms of the <acronym title="GNU's Not Unix">GNU</acronym> Free Documentation License, Version 1.2<br<?php echo $sovix__close_tag; ?>>
or any later version published by the Free Software Foundation;<br<?php echo $sovix__close_tag; ?>>
with no Invariant Sections, no Front-Cover Texts, and no Back-Cover<br<?php echo $sovix__close_tag; ?>>
Texts.  A copy of the license is included in the section entitled &ldquo;<acronym title="GNU's Not Unix">GNU</acronym><br<?php echo $sovix__close_tag; ?>>
Free Documentation License&rdquo;.
<p></p>
You should have received a copy of the <abbr title="GNU's Not Unix">GNU</abbr> Free Documentation License<br<?php echo $sovix__close_tag; ?>>
along with <abbr title="Gnu's Not Unix"<?php if($sovix__xhtml_plus_rdfa==true) echo ' property="dc:source"'; ?>>GNU</abbr> <?php if($sovix__xhtml_plus_rdfa==true) echo '<span property="dc:title">'; ?>Sovix<? if($sovix__xhtml_plus_rdfa==true) echo '</span>'; ?>.  If not, see <a href="http://www.gnu.org/copyleft/fdl.html">&#60;http://www.gnu.org/licenses/&#62;</a>.
<p></p>
See <?php sovix__local_link($sovix__local_link__link="$sovix__url__sovix/COPYING.DOC",$sovix__local_link__text="&#60;$sovix__url__sovix/COPYING.DOC&#62;"); ?> for the full text of that license.

<p></p>
<h3><?php if($sovix__xhtml_plus_rdfa==true) echo '<span property="dc:rights">'; ?><acronym title="GNU's Not Unix">GNU</acronym> General Public License<? if($sovix__xhtml_plus_rdfa==true) echo '</span>'; ?></h3>
All artwork is distributed under the terms of the <?php if($sovix__xhtml_plus_rdfa==true) echo '<span property="dc:rights">'; ?><acronym title="GNU's Not Unix">GNU</acronym> General Public License<? if($sovix__xhtml_plus_rdfa==true) echo '</span>'; ?><br<?php echo $sovix__close_tag; ?>> either version 3 of the License, or (at your option) any later version.
<p></p>
You should have received a copy of the <?php if($sovix__xhtml_plus_rdfa==true) echo '<span property="dc:rights">'; ?><acronym title="GNU's Not Unix">GNU</acronym> General Public License<? if($sovix__xhtml_plus_rdfa==true) echo '</span>'; ?><br<?php echo $sovix__close_tag; ?>>
along with <abbr title="Gnu's Not Unix"<?php if($sovix__xhtml_plus_rdfa==true) echo ' property="dc:source"'; ?>>GNU</abbr> <?php if($sovix__xhtml_plus_rdfa==true) echo '<span property="dc:title">'; ?>Sovix<? if($sovix__xhtml_plus_rdfa==true) echo '</span>'; ?>.  If not, see <a href="http://artlibre.org/licence/lal/en/">&#60;http://www.gnu.org/licenses/&#62;</a>.
<p></p>
See <?php sovix__local_link($sovix__local_link__link="$sovix__url__sovix/COPYING.ART",$sovix__local_link__text="&#60;$sovix__url__sovix/COPYING.ART&#62;"); ?> for the full text of that license.

<?php require_once "$sovix__directory__src/footer.inc"; ?>

==> sovix-0.0.1.6-rc3.tar.gz: sovix-0.0.1.6-rc3/Copyright.php <==
<?php /* Copyright (C) 2006, 2007, 2008 David Englund.

This file is part of GNU Sovix.

GNU Sovix is free software: you can redistribute it and/or modify
it under the terms of the GNU Affero General Public License as
published by the Free Software Foundation, either version 3 of the
License, or (at your option) any later version.

GNU Sovix is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU Affero General Public License for more details.

You should have received a copy of the GNU Affero General Public License
along with GNU Sovix.  If not, see <http://www.gnu.org/licenses/>.

The text in $sovix__page__copyright doesn't apply to this file, but
rather to the pages it generates. */

$sovix__page__copyright="Copyright (C) 2006, 2007, 2008 David Englund.
Permission is granted to copy, distribute and/or modify this document
under the terms of the GNU Free Documentation License, Version 1.2 or any
later version published by the Free Software Foundation; with no Invariant
Sections, with no Front-Cover Texts, and with no Back-Cover Texts.";
$sovix__directory__src=$_SERVER['DOCUMENT_ROOT']."/sovix/src";
$sovix__directory__dotsovix=$_SERVER['DOCUMENT_ROOT']."/sovix/dotsovix";
require_once "$sovix__directory__src/header.inc"; ?>

<abbr title="Gnu's Not Unix"<?php if($sovix__xhtml_plus_rdfa==true) echo ' property="dc:source"'; ?>>GNU</abbr> <?php if($sovix__xhtml_plus_rdfa==true) echo '<span property="dc:title">'; ?>Sovix<? if($sovix__xhtml_plus_rdfa==true) echo '</span>'; ?> wesite revision system version 0.0.1.6-rc3 is Copyright (C) 2006, 2007, 2008 David Englund.

<p></p>
<h3><?php if($sovix__xhtml_plus_rdfa==true) echo '<span property="dc:rights">'; ?><acronym title="GNU's Not Unix">GNU</acronym> Affero General Public License<? if($sovix__xhtml_plus_rdfa==true) echo '</span>'; ?></h3>
<p></p>
<abbr title="Gnu's Not Unix"<?php if($sovix__xhtml_plus_rdfa==true) echo ' property="dc:source"'; ?>>GNU</abbr> <?php if($sovix__xhtml_plus_rdfa==true) echo '<span property="dc:title">'; ?>Sovix<? if($sovix__xhtml_plus_rdfa==true) echo '</span>'; ?> is free software: you can redistribute it and/or modify<br<?php echo $sovix__close_tag; ?>>
it under the terms of the <?php if($sovix__xhtml_plus_rdfa==true) echo '<span property="dc:rights">'; ?><acronym title="GNU's Not Unix">GNU</acronym> Affero General Public License<? if($sovix__xhtml_plus_rdfa==true) echo '</span>'; ?> as published by<br<?php echo $sovix__close_tag; ?>>
published by the Free Software Foundation, either version 3 of the<br<?php echo $sovix__close_tag; ?>>
License, or (at your option) any later version.
<p></p>
<abbr title="Gnu's Not Unix"<?php if($sovix__xhtml_plus_rdfa==true) echo ' property="dc:source"'; ?>>GNU</abbr> <?php if($sovix__xhtml_plus_rdfa==true) echo '<span property="dc:title">'; ?>Sovix<? if($sovix__xhtml_plus_rdfa==true) echo '</span>'; ?> is distributed in the hope that it will be useful,<br<?php echo $sovix__close_tag; ?>>
but WITHOUT ANY WARRANTY; without even the implied warranty of<br<?php echo $sovix__close_tag; ?>>
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the<br<?php echo $sovix__close_tag; ?>>
<?php if($sovix__xhtml_plus_rdfa==true) echo '<span property="dc:rights">'; ?><acronym title="GNU's Not Unix">GNU</acronym> Affero General Public License<? if($sovix__xhtml_plus_rdfa==true) echo '</span>'; ?> for more details.<br<?php echo $sovix__close_tag; ?>>
<p></p>
The toolbar icons is copied from Emacs, copyright Free Software Foundation.
<p></p>
You should have received a copy of the <?php if($sovix__xhtml_plus_rdfa==true) echo '<span property="dc:rights">'; ?><acronym title="GNU's Not Unix">GNU</acronym> Affero General Public License<? if($sovix__xhtml_plus_rdfa==true) echo '</span>'; ?><br<?php echo $sovix__close_tag; ?>>
along with <abbr title="Gnu's Not Unix"<?php if($sovix__xhtml_plus_rdfa==true) echo ' property="dc:source"'; ?>>GNU</abbr> <?php if($sovix__xhtml_plus_rdfa==true) echo '<span property="dc:title">'; ?>Sovix<? if($sovix__xhtml_plus_rdfa==true) echo '</span>'; ?>.  If not, see <a href="http://www.gnu.org/licenses/">&#60;http://www.gnu.org/licenses/&#62;</a>.<br<?php echo $sovix__close_tag; ?>>
<p></p>
See <?php sovix__local_link($sovix__local_link__link="$sovix__url__sovix/COPYING",$sovix__local_link__text="&#60;$sovix__url__sovix/COPYING&#62;"); ?> for the full text of that license.

<p></p>
<h3><acronym title="GNU's Not Unix">GNU</acronym> Free Documentation License</h3>
Permission is granted to copy, distribute and/or modify <?php if($sovix__xhtml_plus_rdfa==true) echo '<span property="dc:title">'; ?>Sovix<? if($sovix__xhtml_plus_rdfa==true) echo '</span>'; ?> documents<br<?php echo $sovix__close_tag; ?>>
under the terms of the <acronym title="GNU's Not Unix">GNU</acronym> Free Documentation License, Version 1.2<br<?php echo $sovix__close_tag; ?>>
or any later version published by the Free Software Foundation;<br<?php echo $sovix__close_tag; ?>>
with no Invariant Sections, no Front-Cover Texts, and no Back-Cover<br<?php echo $sovix__close_tag; ?>>
Texts.  A copy of the license is included in the section entitled &ldquo;<acronym title="GNU's Not Unix">GNU</acronym><br<?php echo $sovix__close_tag; ?>>
Free Documentation License&rdquo;.
<p></p>
You should have received a copy of the <abbr title="GNU's Not Unix">GNU</abbr> Free Documentation License<br<?php echo $sovix__close_tag; ?>>
along with <abbr title="Gnu's Not Unix"<?php if($sovix__xhtml_plus_rdfa==true) echo ' property="dc:source"'; ?>>GNU</abbr> <?php if($sovix__xhtml_plus_rdfa==true) echo '<span property="dc:title">'; ?>Sovix<? if($sovix__xhtml_plus_rdfa==true) echo '</span>'; ?>.  If not, see <a href="http://www.gnu.org/copyleft/fdl.html">&#60;http://www.gnu.org/licenses/&#62;</a>.
<p></p>
See <?php sovix__local_link($sovix__local_link__link="$sovix__url__sovix/COPYING.DOC",$sovix__local_link__text="&#60;$sovix__url__sovix/COPYING.DOC&#62;"); ?> for the full text of that license.

<p></p>
<h3><?php if($sovix__xhtml_plus_rdfa==true) echo '<span property="dc:rights">'; ?><acronym title="GNU's Not Unix">GNU</acronym> General Public License<? if($sovix__xhtml_plus_rdfa==true) echo '</span>'; ?></h3>
All artwork is distributed under the terms of the <?php if($sovix__xhtml_plus_rdfa==true) echo '<span property="dc:rights">'; ?><acronym title="GNU's Not Unix">GNU</acronym> General Public License<? if($sovix__xhtml_plus_rdfa==true) echo '</span>'; ?><br<?php echo $sovix__close_tag; ?>> either version 3 of the License, or (at your option) any later version.
<p></p>
You should have received a copy of the <?php if($sovix__xhtml_plus_rdfa==true) echo '<span property="dc:rights">'; ?><acronym title="GNU's Not Unix">GNU</acronym> General Public License<? if($sovix__xhtml_plus_rdfa==true) echo '</span>'; ?><br<?php echo $sovix__close_tag; ?>>
along with <abbr title="Gnu's Not Unix"<?php if($sovix__xhtml_plus_rdfa==true) echo ' property="dc:source"'; ?>>GNU</abbr> <?php if($sovix__xhtml_plus_rdfa==true) echo '<span property="dc:title">'; ?>Sovix<? if($sovix__xhtml_plus_rdfa==true) echo '</span>'; ?>.  If not, see <a href="http://artlibre.org/licence/lal/en/">&#60;http://www.gnu.org/licenses/&#62;</a>.
<p></p>
See <?php sovix__local_link($sovix__local_link__link="$sovix__url__sovix/COPYING.ART",$sovix__local_link__text="&#60;$sovix__url__sovix/COPYING.ART&#62;"); ?> for the full text of that license.

<?php require_once "$sovix__directory__src/footer.inc"; ?>
